#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_EXPONENTBITS_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_EXPONENTBITS_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/simd/exponentbits.hpp>

#endif
